package net.wanji.utc.service.control.impl;

import com.alibaba.fastjson.JSONObject;
import lombok.RequiredArgsConstructor;
import net.wanji.common.framework.rest.JsonViewObject;
import net.wanji.utc.po.hk.request.DelBaseConfigPO;
import net.wanji.utc.service.control.ControlCommandService;
import net.wanji.utc.util.HttpRestUtil;
import net.wanji.utc.util.StringUtils;
import net.wanji.utc.vo.*;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.util.HashMap;

/**
 * @author duanruiming
 * @date 2023/01/12 13:18
 */
@Service("wanJiControlCommandService")
@RequiredArgsConstructor
public class WanJiControlCommandServiceImpl implements ControlCommandService {

    private final HttpRestUtil httpRestUtil;
    @Value("url")
    private String rpcUri;

    /**
     * @param schemeSendVO
     * @return
     * @throws Exception
     */
    @Override
    public JsonViewObject schemeSend(SchemeSendVO schemeSendVO) throws Exception {
        JsonViewObject jsonViewObject = rpcService(httpRestUtil, rpcUri, null, JSONObject.toJSONString(schemeSendVO));
        if (StringUtils.endsWithIgnoreCase("success", jsonViewObject.getStatus())) {
            return jsonViewObject.success("万集标准协议下发方案成功！");
        }
        return jsonViewObject;
    }

    @Override
    public JsonViewObject planSend(PlanSendVO planSendVO) throws Exception {
        JsonViewObject jsonViewObject = rpcService(httpRestUtil, rpcUri, null, JSONObject.toJSONString(planSendVO));
        if (StringUtils.endsWithIgnoreCase("success", jsonViewObject.getStatus())) {
            return jsonViewObject.success("万集标准协议下发计划成功！");
        }
        return jsonViewObject;
    }

    @Override
    public JsonViewObject scheduleSend(ScheduleSendVO scheduleSendVO) throws Exception {
        JsonViewObject jsonViewObject = rpcService(httpRestUtil, rpcUri, null, JSONObject.toJSONString(scheduleSendVO));
        if (StringUtils.endsWithIgnoreCase("success", jsonViewObject.getStatus())) {
            return jsonViewObject.success("万集标准协议下发时间表成功！");
        }
        return jsonViewObject;
    }

    @Override
    public JsonViewObject lockControl(ControlCommandVO commandVO) throws Exception {
        JsonViewObject jsonViewObject = rpcService(httpRestUtil, rpcUri, null, JSONObject.toJSONString(commandVO));
        if (StringUtils.endsWithIgnoreCase("success", jsonViewObject.getStatus())) {
            return jsonViewObject.success("万集标准协议锁定控制成功！");
        }
        return jsonViewObject;
    }

    @Override
    public JsonViewObject stepControl(String crossId, Integer command, Integer stepNum) throws Exception {
        HashMap<String, Object> paraMap = new HashMap<>();
        paraMap.put("crossId", crossId);
        paraMap.put("command", command);
        paraMap.put("stepNum", stepNum);
        JsonViewObject jsonViewObject = rpcService(httpRestUtil, rpcUri, null, JSONObject.toJSONString(paraMap));
        if (StringUtils.endsWithIgnoreCase("success", jsonViewObject.getStatus())) {
            return jsonViewObject.success("万集标准协议步进控制成功！");
        }
        return jsonViewObject;
    }

    @Override
    public JsonViewObject setSignalControl(String crossId, Integer command, Integer commandType) throws Exception {
        HashMap<String, Object> paraMap = new HashMap<>();
        paraMap.put("crossId", crossId);
        paraMap.put("command", command);
        paraMap.put("commandType", commandType);
        JsonViewObject jsonViewObject = rpcService(httpRestUtil, rpcUri, null, JSONObject.toJSONString(paraMap));
        if (StringUtils.endsWithIgnoreCase("success", jsonViewObject.getStatus())) {
            return jsonViewObject.success("万集标准协议设置信号机控制模式成功！");
        }
        return jsonViewObject;
    }

    @Override
    public JsonViewObject recoverSchedule(String crossId) throws Exception {
        HashMap<String, Object> paraMap = new HashMap<>();
        paraMap.put("crossId", crossId);
        JsonViewObject jsonViewObject = rpcService(httpRestUtil, rpcUri, null, JSONObject.toJSONString(paraMap));
        if (StringUtils.endsWithIgnoreCase("success", jsonViewObject.getStatus())) {
            return jsonViewObject.success("万集标准协议恢复时间表成功！");
        }
        return jsonViewObject;
    }

    @Override
    public JsonViewObject phaseTimingSend(PhaseTimingSendVO phaseTimingSendVO) throws Exception {
        JsonViewObject jsonViewObject = rpcService(httpRestUtil, rpcUri, null, JSONObject.toJSONString(phaseTimingSendVO));
        if (StringUtils.endsWithIgnoreCase("success", jsonViewObject.getStatus())) {
            return jsonViewObject.success("万集标准协议下发相位配时成功！");
        }
        return jsonViewObject;
    }

    @Override
    public JsonViewObject phaseDiffSend() {
        return null;
    }

    @Override
    public JsonViewObject delBaseConfig(DelBaseConfigPO delBaseConfigPO) {
        return null;
    }
}
